from django.contrib import admin

from ..models import Fattura
from .fattura_rata import FatturaRataAdminInline
from .fattura_riepilogo_iva import FatturaRiepilogoIVAAdmin


@admin.register(Fattura)
class FatturaAdmin(admin.ModelAdmin):
    ordering = ("-data_sdi",)
    list_display = (
        "numero",
        "data",
        "fornitore",
        "cliente",
        "importo_totale_documento",
    )

    search_fields = [
        "fornitore__denominazione",
        "fornitore__nome",
        "fornitore__cognome",
        "fornitore__id_fiscale_iva_codice",
        "cliente__denominazione",
        "cliente__nome",
        "cliente__cognome",
        "cliente__id_fiscale_iva_codice",
        "data",
        "data_sdi",
        "numero",
    ]

    list_filter = ("tipo_documento",)

    inlines = [FatturaRiepilogoIVAAdmin, FatturaRataAdminInline]

    fieldsets = (
        (
            None,
            {
                "fields": (
                    "fornitore",
                    "cliente",
                ),
            },
        ),
        (
            None,
            {
                "fields": (
                    "tipo_documento",
                    (
                        "art_73",
                        "numero",
                    ),
                    (
                        "data",
                        "data_sdi",
                    ),
                )
            },
        ),
        (
            "Riepilogo",
            {
                "fields": ("importo_totale_documento",),
            },
        ),
    )
