from django.db import models


class Tributo(models.Model):
    soggetto_fiscale = models.ForeignKey(
        "anagrafica.SoggettoFiscale", on_delete=models.CASCADE, related_name="tributi"
    )

    data_scadenza = models.DateField()

    descrizione = models.CharField(max_length=100)

    @property
    def debito(self):
        totale = 0

        for erario in self.sezione_erario.all():
            totale += erario.debito
        for inps in self.sezione_inps.all():
            totale += inps.debito
        for regione in self.sezione_regioni.all():
            totale += regione.debito
        for imu in self.sezione_imu_tributi_locali.all():
            totale += imu.debito
        for inail in self.sezione_inail.all():
            totale += inail.debito
        for altro in self.sezione_altri_enti.all():
            totale += altro.debito

        return totale

    @property
    def credito(self):
        totale = 0

        for erario in self.sezione_erario.all():
            totale += erario.credito
        for inps in self.sezione_inps.all():
            totale += inps.credito
        for regione in self.sezione_regioni.all():
            totale += regione.credito
        for imu in self.sezione_imu_tributi_locali.all():
            totale += imu.credito
        for inail in self.sezione_inail.all():
            totale += inail.credito
        for altro in self.sezione_altri_enti.all():
            totale += altro.credito

        return totale

    @property
    def totale(self):
        return self.debito - self.credito

    def __str__(self):
        return f"Tributo {self.descrizione}"

    class Meta:
        verbose_name_plural = "Tributi"
